# Histogram

A pandas extension to open Dataframes & Series in [histogram.dev](https://histogram.dev).


## Usage/Examples

```python
import histogram # Import at least once, anywhere

df.histogram.plot()

```

